@@ -29,6 +29,8 @@ class InvoiceFee(BaseModel):
     unit_amount_cents: Optional[int]
     units: Optional[float]
     description: Optional[str]
+    from_datetime: Optional[str]
+    to_datetime: Optional[str]
     invoice_display_name: Optional[str]
     tax_codes: Optional[List[str]]
 
